@@ -13,11 +13,18 @@ Support for the Microsoft Access database.
 """
 from sqlalchemy import sql, schema, types, exc, pool
 from sqlalchemy.sql import compiler, expression
+from sqlalchemy.sql.compiler import OPERATORS
+from sqlalchemy.sql.operators import ne, is_, isnot
 from sqlalchemy.engine import default, base, reflection
 from sqlalchemy import processors
 
 import pyodbc
 
+# The != operator override is required in order to make
+# the AccessCompiler class correctly format emitted queries
+OPERATORS[ne] =  " <> "
+
+
 # AutoNumber
 class COUNTER(types.Integer):
     __visit_name__ = "COUNTER"
@@ -607,6 +614,8 @@ class AccessDialect(default.DefaultDialect):
     supports_simple_order_by_label = False
     _need_decimal_fix = False
 
+    supports_is_distinct_from = False
+
     poolclass = pool.SingletonThreadPool
     statement_compiler = AccessCompiler
     ddl_compiler = AccessDDLCompiler
